"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.iot.devices.v1.device_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    DEVICE_VIEW_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device to return.

    To get a device ID make a [DeviceService.List] request.
    """
    device_view: yandex.cloud.iot.devices.v1.device_pb2.DeviceView.ValueType
    """Specifies which parts of the device resource should be returned
    in the response.
    """
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        device_view: yandex.cloud.iot.devices.v1.device_pb2.DeviceView.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id", "device_view", b"device_view"]) -> None: ...

global___GetDeviceRequest = GetDeviceRequest

@typing.final
class GetByNameDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    DEVICE_VIEW_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry to get device.

    To get a registry ID make a [yandex.cloud.iot.devices.v1.RegistryService.List] request.
    """
    device_name: builtins.str
    """Name of the device to return.

    To get a device name make a [DeviceService.List] request.
    """
    device_view: yandex.cloud.iot.devices.v1.device_pb2.DeviceView.ValueType
    """Specifies which parts of the device resource should be returned
    in the response.
    """
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        device_name: builtins.str = ...,
        device_view: yandex.cloud.iot.devices.v1.device_pb2.DeviceView.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name", "device_view", b"device_view", "registry_id", b"registry_id"]) -> None: ...

global___GetByNameDeviceRequest = GetByNameDeviceRequest

@typing.final
class ListDevicesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    DEVICE_VIEW_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry to list devices in.

    To get a registry ID make a [yandex.cloud.iot.devices.v1.RegistryService.List] request.
    """
    folder_id: builtins.str
    """ID of the folder to list devices in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListDevicesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListDevicesResponse.next_page_token] returned by a previous list request.
    """
    device_view: yandex.cloud.iot.devices.v1.device_pb2.DeviceView.ValueType
    """Specifies which parts of the device resource should be returned
    in the response.
    """
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        device_view: yandex.cloud.iot.devices.v1.device_pb2.DeviceView.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["folder_id", b"folder_id", "id", b"id", "registry_id", b"registry_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["device_view", b"device_view", "folder_id", b"folder_id", "id", b"id", "page_size", b"page_size", "page_token", b"page_token", "registry_id", b"registry_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["id", b"id"]) -> typing.Literal["registry_id", "folder_id"] | None: ...

global___ListDevicesRequest = ListDevicesRequest

@typing.final
class ListDevicesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListDevicesRequest.page_size], use `next_page_token` as the value
    for the [ListDevicesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def devices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iot.devices.v1.device_pb2.Device]:
        """List of devices."""

    def __init__(
        self,
        *,
        devices: collections.abc.Iterable[yandex.cloud.iot.devices.v1.device_pb2.Device] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["devices", b"devices", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDevicesResponse = ListDevicesResponse

@typing.final
class CreateDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class TopicAliasesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class Certificate(google.protobuf.message.Message):
        """Specification of a device certificate."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CERTIFICATE_DATA_FIELD_NUMBER: builtins.int
        certificate_data: builtins.str
        """Public part of the device certificate."""
        def __init__(
            self,
            *,
            certificate_data: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["certificate_data", b"certificate_data"]) -> None: ...

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CERTIFICATES_FIELD_NUMBER: builtins.int
    TOPIC_ALIASES_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry to create a device in.

    To get a registry ID, make a [yandex.cloud.iot.devices.v1.RegistryService.List] request.
    """
    name: builtins.str
    """Name of the device. The name must be unique within the registry."""
    description: builtins.str
    """Description of the device."""
    password: builtins.str
    """Device password.

    The password must contain at least three character categories among the following: upper case latin, lower case latin, numbers and special symbols.
    """
    @property
    def certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CreateDeviceRequest.Certificate]:
        """Device certificate."""

    @property
    def topic_aliases(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Alias of a device topic.

        Alias is an alternate name of a device topic assigned by the user. Map alias to canonical topic name prefix, e.g. `my/custom/alias` match to `$device/{id}/events`.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        certificates: collections.abc.Iterable[global___CreateDeviceRequest.Certificate] | None = ...,
        topic_aliases: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        password: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificates", b"certificates", "description", b"description", "labels", b"labels", "name", b"name", "password", b"password", "registry_id", b"registry_id", "topic_aliases", b"topic_aliases"]) -> None: ...

global___CreateDeviceRequest = CreateDeviceRequest

@typing.final
class CreateDeviceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device that is being created."""
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id"]) -> None: ...

global___CreateDeviceMetadata = CreateDeviceMetadata

@typing.final
class UpdateDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class TopicAliasesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEVICE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TOPIC_ALIASES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device to update.

    To get a device ID make a [DeviceService.List] request.
    """
    name: builtins.str
    """Name of the device. The name must be unique within the registry."""
    description: builtins.str
    """Description of the device."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the device are going to be updated."""

    @property
    def topic_aliases(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Alias of a device topic.

        Alias is an alternate name of a device topic assigned by the user. Map alias to canonical topic name prefix, e.g. `my/custom/alias` match to `$device/{id}/events`.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        topic_aliases: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "device_id", b"device_id", "labels", b"labels", "name", b"name", "topic_aliases", b"topic_aliases", "update_mask", b"update_mask"]) -> None: ...

global___UpdateDeviceRequest = UpdateDeviceRequest

@typing.final
class UpdateDeviceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device that is being updated."""
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id"]) -> None: ...

global___UpdateDeviceMetadata = UpdateDeviceMetadata

@typing.final
class DeleteDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device to delete.

    To get a device ID make a [DeviceService.List] request.
    """
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id"]) -> None: ...

global___DeleteDeviceRequest = DeleteDeviceRequest

@typing.final
class DeleteDeviceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device that is being deleted."""
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id"]) -> None: ...

global___DeleteDeviceMetadata = DeleteDeviceMetadata

@typing.final
class ListDeviceCertificatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device to list certificates for."""
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id"]) -> None: ...

global___ListDeviceCertificatesRequest = ListDeviceCertificatesRequest

@typing.final
class ListDeviceCertificatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATES_FIELD_NUMBER: builtins.int
    @property
    def certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iot.devices.v1.device_pb2.DeviceCertificate]:
        """List of certificates for the specified device."""

    def __init__(
        self,
        *,
        certificates: collections.abc.Iterable[yandex.cloud.iot.devices.v1.device_pb2.DeviceCertificate] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificates", b"certificates"]) -> None: ...

global___ListDeviceCertificatesResponse = ListDeviceCertificatesResponse

@typing.final
class AddDeviceCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    CERTIFICATE_DATA_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device for which the certificate is being added.

    To get a device ID make a [DeviceService.List] request.
    """
    certificate_data: builtins.str
    """Public part of the certificate."""
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        certificate_data: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_data", b"certificate_data", "device_id", b"device_id"]) -> None: ...

global___AddDeviceCertificateRequest = AddDeviceCertificateRequest

@typing.final
class AddDeviceCertificateMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device certificate that is being added."""
    fingerprint: builtins.str
    """Fingerprint of the certificate that is being added."""
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        fingerprint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id", "fingerprint", b"fingerprint"]) -> None: ...

global___AddDeviceCertificateMetadata = AddDeviceCertificateMetadata

@typing.final
class DeleteDeviceCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device to delete a certificate for.

    To get a device ID make a [DeviceService.List] request.
    """
    fingerprint: builtins.str
    """Fingerprint of the certificate to delete."""
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        fingerprint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id", "fingerprint", b"fingerprint"]) -> None: ...

global___DeleteDeviceCertificateRequest = DeleteDeviceCertificateRequest

@typing.final
class DeleteDeviceCertificateMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device certificate that is being deleted."""
    fingerprint: builtins.str
    """Fingerprint of the certificate that is being deleted."""
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        fingerprint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id", "fingerprint", b"fingerprint"]) -> None: ...

global___DeleteDeviceCertificateMetadata = DeleteDeviceCertificateMetadata

@typing.final
class ListDevicePasswordsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the registry to list passwords in.

    To get a registry ID make a [RegistryService.List] request.
    """
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id"]) -> None: ...

global___ListDevicePasswordsRequest = ListDevicePasswordsRequest

@typing.final
class ListDevicePasswordsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PASSWORDS_FIELD_NUMBER: builtins.int
    @property
    def passwords(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iot.devices.v1.device_pb2.DevicePassword]:
        """List of passwords for the specified device."""

    def __init__(
        self,
        *,
        passwords: collections.abc.Iterable[yandex.cloud.iot.devices.v1.device_pb2.DevicePassword] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["passwords", b"passwords"]) -> None: ...

global___ListDevicePasswordsResponse = ListDevicePasswordsResponse

@typing.final
class AddDevicePasswordRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device to add a password for.

    To get a device ID make a [DeviceService.List] request.
    """
    password: builtins.str
    """Passwords for the device.

    The password must contain at least three character categories among the following: upper case latin, lower case latin, numbers and special symbols.
    """
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id", "password", b"password"]) -> None: ...

global___AddDevicePasswordRequest = AddDevicePasswordRequest

@typing.final
class AddDevicePasswordMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    PASSWORD_ID_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device for which the password is being added."""
    password_id: builtins.str
    """ID of the password that is being added."""
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        password_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id", "password_id", b"password_id"]) -> None: ...

global___AddDevicePasswordMetadata = AddDevicePasswordMetadata

@typing.final
class DeleteDevicePasswordRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    PASSWORD_ID_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device to delete a password for.

    To get a device ID make a [DeviceService.List] request.
    """
    password_id: builtins.str
    """ID of the password to delete.

    To get a password ID make a [DeviceService.ListPasswords] request.
    """
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        password_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id", "password_id", b"password_id"]) -> None: ...

global___DeleteDevicePasswordRequest = DeleteDevicePasswordRequest

@typing.final
class DeleteDevicePasswordMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    PASSWORD_ID_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device for which the password is being deleted."""
    password_id: builtins.str
    """ID of the password that is being deleted."""
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        password_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id", "password_id", b"password_id"]) -> None: ...

global___DeleteDevicePasswordMetadata = DeleteDevicePasswordMetadata

@typing.final
class ListDeviceOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device to list operations for.

    To get a device ID make a [DeviceService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `page_size`, the service returns a [ListDeviceOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListDeviceOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    Currently you can use filtering only on [Device.name] field.
    """
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDeviceOperationsRequest = ListDeviceOperationsRequest

@typing.final
class ListDeviceOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListDeviceOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListDeviceOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified device certificate."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListDeviceOperationsResponse = ListDeviceOperationsResponse



import json
from enum import Enum
from typing import Any, Dict, Tuple

import grpc


class ThrottlingMode(str, Enum):
    PERSISTENT = "persistent"
    TEMPORARY = "temporary"


def get_throttling_policy(throttling_mode: ThrottlingMode) -> Dict[str, Any]:
    if throttling_mode == ThrottlingMode.PERSISTENT:
        return {"maxTokens": 100, "tokenRatio": 0.1}

    return {"maxTokens": 6, "tokenRatio": 0.1}


class RetryPolicy:
    def __init__(
        self,
        max_attempts: int = 4,
        status_codes: Tuple["grpc.StatusCode"] = (grpc.StatusCode.UNAVAILABLE,),
        throttling_mode: ThrottlingMode = ThrottlingMode.TEMPORARY,
    ):
        self.__policy = {
            "methodConfig": [
                {
                    "name": [{}],
                    "retryPolicy": {
                        "maxAttempts": max_attempts,
                        "initialBackoff": "0.1s",
                        "maxBackoff": "20s",
                        "backoffMultiplier": 2,
                        "retryableStatusCodes": [status.name for status in status_codes],
                    },
                    "waitForReady": True,
                }
            ],
            "retryThrottling": get_throttling_policy(throttling_mode),
        }

    def to_json(self) -> str:
        return json.dumps(self.__policy)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/monitoring/v3/title_widget.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/monitoring/v3/title_widget.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/monitoring/v3/title_widget.proto\x12\x1ayandex.cloud.monitoring.v3\"\xce\x01\n\x0bTitleWidget\x12\x0c\n\x04text\x18\x01 \x01(\t\x12?\n\x04size\x18\x02 \x01(\x0e\x32\x31.yandex.cloud.monitoring.v3.TitleWidget.TitleSize\"p\n\tTitleSize\x12\x1a\n\x16TITLE_SIZE_UNSPECIFIED\x10\x00\x12\x11\n\rTITLE_SIZE_XS\x10\x01\x12\x10\n\x0cTITLE_SIZE_S\x10\x02\x12\x10\n\x0cTITLE_SIZE_M\x10\x03\x12\x10\n\x0cTITLE_SIZE_L\x10\x04\x42k\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.title_widget_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _globals['_TITLEWIDGET']._serialized_start=78
  _globals['_TITLEWIDGET']._serialized_end=284
  _globals['_TITLEWIDGET_TITLESIZE']._serialized_start=172
  _globals['_TITLEWIDGET_TITLESIZE']._serialized_end=284
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/talk_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/talk_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.speechsense.v1 import audio_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_audio__pb2
from yandex.cloud.speechsense.v1 import text_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_text__pb2
from yandex.cloud.speechsense.v1 import search_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_search__pb2
from yandex.cloud.speechsense.v1 import talk_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/speechsense/v1/talk_service.proto\x12\x1byandex.cloud.speechsense.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\'yandex/cloud/speechsense/v1/audio.proto\x1a&yandex/cloud/speechsense/v1/text.proto\x1a(yandex/cloud/speechsense/v1/search.proto\x1a&yandex/cloud/speechsense/v1/talk.proto\"\xa0\x01\n\x11StreamTalkRequest\x12=\n\x08metadata\x18\x01 \x01(\x0b\x32).yandex.cloud.speechsense.v1.TalkMetadataH\x00\x12\x43\n\x05\x61udio\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.speechsense.v1.AudioStreamingRequestH\x00\x42\x07\n\x05\x45vent\"\x9b\x01\n\x11UploadTalkRequest\x12\x0f\n\x07talk_id\x18\x03 \x01(\t\x12;\n\x08metadata\x18\x01 \x01(\x0b\x32).yandex.cloud.speechsense.v1.TalkMetadata\x12\x38\n\x05\x61udio\x18\x02 \x01(\x0b\x32).yandex.cloud.speechsense.v1.AudioRequest\"%\n\x12UploadTalkResponse\x12\x0f\n\x07talk_id\x18\x01 \x01(\t\"\xa1\x01\n\x11UploadTextRequest\x12\x0f\n\x07talk_id\x18\x03 \x01(\t\x12;\n\x08metadata\x18\x01 \x01(\x0b\x32).yandex.cloud.speechsense.v1.TalkMetadata\x12>\n\x0ctext_content\x18\x02 \x01(\x0b\x32(.yandex.cloud.speechsense.v1.TextContent\"%\n\x12UploadTextResponse\x12\x0f\n\x07talk_id\x18\x01 \x01(\t\"\xd5\x01\n\x0cTalkMetadata\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x45\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x35.yandex.cloud.speechsense.v1.TalkMetadata.FieldsEntry\x12\x38\n\x05users\x18\x03 \x03(\x0b\x32).yandex.cloud.speechsense.v1.UserMetadata\x1a-\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc5\x01\n\x0cUserMetadata\x12\n\n\x02id\x18\x01 \x01(\t\x12\x33\n\x04role\x18\x02 \x01(\x0e\x32%.yandex.cloud.speechsense.v1.UserRole\x12\x45\n\x06\x66ields\x18\x03 \x03(\x0b\x32\x35.yandex.cloud.speechsense.v1.UserMetadata.FieldsEntry\x1a-\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb3\x02\n\x11SearchTalkRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\x10\n\x08space_id\x18\x02 \x01(\t\x12\x15\n\rconnection_id\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x34\n\x07\x66ilters\x18\x05 \x03(\x0b\x32#.yandex.cloud.speechsense.v1.Filter\x12\x31\n\x05query\x18\x06 \x01(\x0b\x32\".yandex.cloud.speechsense.v1.Query\x12\x11\n\tpage_size\x18\x07 \x01(\x03\x12\x12\n\npage_token\x18\x08 \x01(\t\x12\x38\n\tsort_data\x18\t \x01(\x0b\x32%.yandex.cloud.speechsense.v1.SortData\"T\n\x12SearchTalkResponse\x12\x10\n\x08talk_ids\x18\x01 \x03(\t\x12\x13\n\x0btalks_count\x18\x02 \x01(\x03\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"\xaa\x01\n\x0eGetTalkRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\x10\n\x08space_id\x18\x02 \x01(\t\x12\x15\n\rconnection_id\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x10\n\x08talk_ids\x18\x05 \x03(\t\x12\x30\n\x0cresults_mask\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"B\n\x0fGetTalkResponse\x12/\n\x04talk\x18\x01 \x03(\x0b\x32!.yandex.cloud.speechsense.v1.Talk*f\n\x08UserRole\x12\x19\n\x15USER_ROLE_UNSPECIFIED\x10\x00\x12\x16\n\x12USER_ROLE_OPERATOR\x10\x01\x12\x14\n\x10USER_ROLE_CLIENT\x10\x02\x12\x11\n\rUSER_ROLE_BOT\x10\x03\x32\xfe\x04\n\x0bTalkService\x12s\n\x0eUploadAsStream\x12..yandex.cloud.speechsense.v1.StreamTalkRequest\x1a/.yandex.cloud.speechsense.v1.UploadTalkResponse(\x01\x12k\n\x06Upload\x12..yandex.cloud.speechsense.v1.UploadTalkRequest\x1a/.yandex.cloud.speechsense.v1.UploadTalkResponse\"\x00\x12o\n\nUploadText\x12..yandex.cloud.speechsense.v1.UploadTextRequest\x1a/.yandex.cloud.speechsense.v1.UploadTextResponse\"\x00\x12\x92\x01\n\x06Search\x12..yandex.cloud.speechsense.v1.SearchTalkRequest\x1a/.yandex.cloud.speechsense.v1.SearchTalkResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/speechsense/v1/talks/search:\x01*\x12\x86\x01\n\x03Get\x12+.yandex.cloud.speechsense.v1.GetTalkRequest\x1a,.yandex.cloud.speechsense.v1.GetTalkResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/speechsense/v1/talks/get:\x01*B\x80\x01\n\x1fyandex.cloud.api.speechsense.v1B\x10TalkServiceProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.talk_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\020TalkServiceProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_TALKMETADATA_FIELDSENTRY']._loaded_options = None
  _globals['_TALKMETADATA_FIELDSENTRY']._serialized_options = b'8\001'
  _globals['_USERMETADATA_FIELDSENTRY']._loaded_options = None
  _globals['_USERMETADATA_FIELDSENTRY']._serialized_options = b'8\001'
  _globals['_TALKSERVICE'].methods_by_name['Search']._loaded_options = None
  _globals['_TALKSERVICE'].methods_by_name['Search']._serialized_options = b'\202\323\344\223\002!\"\034/speechsense/v1/talks/search:\001*'
  _globals['_TALKSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_TALKSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\036\"\031/speechsense/v1/talks/get:\001*'
  _globals['_USERROLE']._serialized_start=1922
  _globals['_USERROLE']._serialized_end=2024
  _globals['_STREAMTALKREQUEST']._serialized_start=307
  _globals['_STREAMTALKREQUEST']._serialized_end=467
  _globals['_UPLOADTALKREQUEST']._serialized_start=470
  _globals['_UPLOADTALKREQUEST']._serialized_end=625
  _globals['_UPLOADTALKRESPONSE']._serialized_start=627
  _globals['_UPLOADTALKRESPONSE']._serialized_end=664
  _globals['_UPLOADTEXTREQUEST']._serialized_start=667
  _globals['_UPLOADTEXTREQUEST']._serialized_end=828
  _globals['_UPLOADTEXTRESPONSE']._serialized_start=830
  _globals['_UPLOADTEXTRESPONSE']._serialized_end=867
  _globals['_TALKMETADATA']._serialized_start=870
  _globals['_TALKMETADATA']._serialized_end=1083
  _globals['_TALKMETADATA_FIELDSENTRY']._serialized_start=1038
  _globals['_TALKMETADATA_FIELDSENTRY']._serialized_end=1083
  _globals['_USERMETADATA']._serialized_start=1086
  _globals['_USERMETADATA']._serialized_end=1283
  _globals['_USERMETADATA_FIELDSENTRY']._serialized_start=1038
  _globals['_USERMETADATA_FIELDSENTRY']._serialized_end=1083
  _globals['_SEARCHTALKREQUEST']._serialized_start=1286
  _globals['_SEARCHTALKREQUEST']._serialized_end=1593
  _globals['_SEARCHTALKRESPONSE']._serialized_start=1595
  _globals['_SEARCHTALKRESPONSE']._serialized_end=1679
  _globals['_GETTALKREQUEST']._serialized_start=1682
  _globals['_GETTALKREQUEST']._serialized_end=1852
  _globals['_GETTALKRESPONSE']._serialized_start=1854
  _globals['_GETTALKRESPONSE']._serialized_end=1920
  _globals['_TALKSERVICE']._serialized_start=2027
  _globals['_TALKSERVICE']._serialized_end=2665
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PromptTruncationOptions(google.protobuf.message.Message):
    """Defines the options for truncating thread messages within a prompt."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AutoStrategy(google.protobuf.message.Message):
        """Auto truncation strategy.
        No specific parameters are required for this strategy.
        The system will handle truncation in a way that aims to preserve the most relevant context.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class LastMessagesStrategy(google.protobuf.message.Message):
        """Truncates the prompt by retaining only the last `num_messages` messages in the thread."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NUM_MESSAGES_FIELD_NUMBER: builtins.int
        num_messages: builtins.int
        """The number of most recent messages to retain in the prompt.
        If these messages exceed `max_prompt_tokens`, older messages will be further truncated to fit the limit.
        """
        def __init__(
            self,
            *,
            num_messages: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["num_messages", b"num_messages"]) -> None: ...

    MAX_PROMPT_TOKENS_FIELD_NUMBER: builtins.int
    AUTO_STRATEGY_FIELD_NUMBER: builtins.int
    LAST_MESSAGES_STRATEGY_FIELD_NUMBER: builtins.int
    @property
    def max_prompt_tokens(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of tokens allowed in the prompt.
        If the prompt exceeds this limit, the thread messages will be truncated.
        Default max_prompt_tokens: 7000
        """

    @property
    def auto_strategy(self) -> global___PromptTruncationOptions.AutoStrategy: ...
    @property
    def last_messages_strategy(self) -> global___PromptTruncationOptions.LastMessagesStrategy:
        """Retains only the last `num_messages` messages in the thread.
        If these messages exceed `max_prompt_tokens`, older messages will be further truncated to fit the limit.
        """

    def __init__(
        self,
        *,
        max_prompt_tokens: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        auto_strategy: global___PromptTruncationOptions.AutoStrategy | None = ...,
        last_messages_strategy: global___PromptTruncationOptions.LastMessagesStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["TruncationStrategy", b"TruncationStrategy", "auto_strategy", b"auto_strategy", "last_messages_strategy", b"last_messages_strategy", "max_prompt_tokens", b"max_prompt_tokens"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["TruncationStrategy", b"TruncationStrategy", "auto_strategy", b"auto_strategy", "last_messages_strategy", b"last_messages_strategy", "max_prompt_tokens", b"max_prompt_tokens"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["TruncationStrategy", b"TruncationStrategy"]) -> typing.Literal["auto_strategy", "last_messages_strategy"] | None: ...

global___PromptTruncationOptions = PromptTruncationOptions

@typing.final
class CompletionOptions(google.protobuf.message.Message):
    """Defines the options for completion generation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_TOKENS_FIELD_NUMBER: builtins.int
    TEMPERATURE_FIELD_NUMBER: builtins.int
    @property
    def max_tokens(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The limit on the number of tokens used for single completion generation.
        Must be greater than zero. This maximum allowed parameter value may depend on the model being used.
        """

    @property
    def temperature(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """Affects creativity and randomness of responses. Should be a double number between 0 (inclusive) and 1 (inclusive).
        Lower values produce more straightforward responses while higher values lead to increased creativity and randomness.
        Default temperature: 0.3
        """

    def __init__(
        self,
        *,
        max_tokens: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        temperature: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "temperature", b"temperature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "temperature", b"temperature"]) -> None: ...

global___CompletionOptions = CompletionOptions

@typing.final
class Tool(google.protobuf.message.Message):
    """Represents a general tool that can be one of several types."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_INDEX_FIELD_NUMBER: builtins.int
    FUNCTION_FIELD_NUMBER: builtins.int
    @property
    def search_index(self) -> global___SearchIndexTool:
        """SearchIndexTool tool that performs search across specified indexes."""

    @property
    def function(self) -> global___FunctionTool:
        """Function tool that can be invoked by the assistant."""

    def __init__(
        self,
        *,
        search_index: global___SearchIndexTool | None = ...,
        function: global___FunctionTool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolType", b"ToolType", "function", b"function", "search_index", b"search_index"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolType", b"ToolType", "function", b"function", "search_index", b"search_index"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolType", b"ToolType"]) -> typing.Literal["search_index", "function"] | None: ...

global___Tool = Tool

@typing.final
class ToolCall(google.protobuf.message.Message):
    """Represents a call to a tool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_CALL_FIELD_NUMBER: builtins.int
    @property
    def function_call(self) -> global___FunctionCall:
        """Represents a call to a function."""

    def __init__(
        self,
        *,
        function_call: global___FunctionCall | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolCallType", b"ToolCallType", "function_call", b"function_call"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolCallType", b"ToolCallType", "function_call", b"function_call"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolCallType", b"ToolCallType"]) -> typing.Literal["function_call"] | None: ...

global___ToolCall = ToolCall

@typing.final
class ToolCallList(google.protobuf.message.Message):
    """Represents a list of tool calls."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOOL_CALLS_FIELD_NUMBER: builtins.int
    @property
    def tool_calls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ToolCall]:
        """A list of tool calls to be executed."""

    def __init__(
        self,
        *,
        tool_calls: collections.abc.Iterable[global___ToolCall] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tool_calls", b"tool_calls"]) -> None: ...

global___ToolCallList = ToolCallList

@typing.final
class ToolResult(google.protobuf.message.Message):
    """Represents the result of a tool call."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_RESULT_FIELD_NUMBER: builtins.int
    @property
    def function_result(self) -> global___FunctionResult:
        """Represents the result of a function call."""

    def __init__(
        self,
        *,
        function_result: global___FunctionResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolResultType", b"ToolResultType", "function_result", b"function_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolResultType", b"ToolResultType", "function_result", b"function_result"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolResultType", b"ToolResultType"]) -> typing.Literal["function_result"] | None: ...

global___ToolResult = ToolResult

@typing.final
class ToolResultList(google.protobuf.message.Message):
    """Represents a list of tool results."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOOL_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def tool_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ToolResult]:
        """A list of tool results."""

    def __init__(
        self,
        *,
        tool_results: collections.abc.Iterable[global___ToolResult] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tool_results", b"tool_results"]) -> None: ...

global___ToolResultList = ToolResultList

@typing.final
class SearchIndexTool(google.protobuf.message.Message):
    """Configures a tool that enables Retrieval-Augmented Generation (RAG) by allowing the assistant to search across a specified search index."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_INDEX_IDS_FIELD_NUMBER: builtins.int
    MAX_NUM_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def search_index_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of search index IDs that this tool will query. Currently, only a single index ID is supported."""

    @property
    def max_num_results(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of results to return from the search.
        Fewer results may be returned if necessary to fit within the prompt's token limit.
        This ensures that the combined prompt and search results do not exceed the token constraints.
        """

    def __init__(
        self,
        *,
        search_index_ids: collections.abc.Iterable[builtins.str] | None = ...,
        max_num_results: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_num_results", b"max_num_results"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_num_results", b"max_num_results", "search_index_ids", b"search_index_ids"]) -> None: ...

global___SearchIndexTool = SearchIndexTool

@typing.final
class FunctionTool(google.protobuf.message.Message):
    """Represents a function tool that can be invoked by the assistant."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the function."""
    description: builtins.str
    """A description of the function's purpose or behavior."""
    @property
    def parameters(self) -> google.protobuf.struct_pb2.Struct:
        """A JSON Schema that defines the expected parameters for the function.
        The schema should describe the required fields, their types, and any constraints or default values.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        parameters: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["parameters", b"parameters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name", "parameters", b"parameters"]) -> None: ...

global___FunctionTool = FunctionTool

@typing.final
class FunctionCall(google.protobuf.message.Message):
    """Represents the invocation of a function with specific arguments."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ARGUMENTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the function being called."""
    @property
    def arguments(self) -> google.protobuf.struct_pb2.Struct:
        """The structured arguments passed to the function.
        These arguments must adhere to the JSON Schema defined in the corresponding function's parameters.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        arguments: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["arguments", b"arguments"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["arguments", b"arguments", "name", b"name"]) -> None: ...

global___FunctionCall = FunctionCall

@typing.final
class FunctionResult(google.protobuf.message.Message):
    """Represents the result of a function call."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the function that was executed."""
    content: builtins.str
    """The result of the function call, represented as a string.
    This field can be used to store the output of the function.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ContentType", b"ContentType", "content", b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ContentType", b"ContentType", "content", b"content", "name", b"name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ContentType", b"ContentType"]) -> typing.Literal["content"] | None: ...

global___FunctionResult = FunctionResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.organizationmanager.v1.group_mapping_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetGroupMappingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___GetGroupMappingRequest = GetGroupMappingRequest

@typing.final
class GetGroupMappingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_MAPPING_FIELD_NUMBER: builtins.int
    @property
    def group_mapping(self) -> yandex.cloud.organizationmanager.v1.group_mapping_pb2.GroupMapping: ...
    def __init__(
        self,
        *,
        group_mapping: yandex.cloud.organizationmanager.v1.group_mapping_pb2.GroupMapping | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group_mapping", b"group_mapping"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group_mapping", b"group_mapping"]) -> None: ...

global___GetGroupMappingResponse = GetGroupMappingResponse

@typing.final
class CreateGroupMappingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """Federation the group mapping will be created for"""
    enabled: builtins.bool
    """Synchronization status."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "federation_id", b"federation_id"]) -> None: ...

global___CreateGroupMappingRequest = CreateGroupMappingRequest

@typing.final
class CreateGroupMappingMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___CreateGroupMappingMetadata = CreateGroupMappingMetadata

@typing.final
class UpdateGroupMappingRequest(google.protobuf.message.Message):
    """Request for updating group mapping configuration"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """Federation the group mapping update is requested"""
    enabled: builtins.bool
    """A new state of synchronization to update (if mentioned in update_mask)."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """A set of fields that should be updated"""

    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "federation_id", b"federation_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateGroupMappingRequest = UpdateGroupMappingRequest

@typing.final
class UpdateGroupMappingMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___UpdateGroupMappingMetadata = UpdateGroupMappingMetadata

@typing.final
class DeleteGroupMappingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """Federation the group mapping deletion is requested"""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___DeleteGroupMappingRequest = DeleteGroupMappingRequest

@typing.final
class DeleteGroupMappingMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___DeleteGroupMappingMetadata = DeleteGroupMappingMetadata

@typing.final
class UpdateGroupMappingItemsRequest(google.protobuf.message.Message):
    """Request for updating group mapping configuration"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    GROUP_MAPPING_ITEM_DELTAS_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """Federation the group mapping update is requested"""
    @property
    def group_mapping_item_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GroupMappingItemDelta]:
        """A collection of mapping items to add or remove (ignores update_fields)."""

    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        group_mapping_item_deltas: collections.abc.Iterable[global___GroupMappingItemDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id", "group_mapping_item_deltas", b"group_mapping_item_deltas"]) -> None: ...

global___UpdateGroupMappingItemsRequest = UpdateGroupMappingItemsRequest

@typing.final
class GroupMappingItemDelta(google.protobuf.message.Message):
    """Message describes the user's request to change (add or remove) a single group mapping."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Action:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GroupMappingItemDelta._Action.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ACTION_UNSPECIFIED: GroupMappingItemDelta._Action.ValueType  # 0
        ADD: GroupMappingItemDelta._Action.ValueType  # 1
        """Group mapping item is to be added"""
        REMOVE: GroupMappingItemDelta._Action.ValueType  # 2
        """Group mapping item is to be removed"""

    class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
    ACTION_UNSPECIFIED: GroupMappingItemDelta.Action.ValueType  # 0
    ADD: GroupMappingItemDelta.Action.ValueType  # 1
    """Group mapping item is to be added"""
    REMOVE: GroupMappingItemDelta.Action.ValueType  # 2
    """Group mapping item is to be removed"""

    ITEM_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    action: global___GroupMappingItemDelta.Action.ValueType
    @property
    def item(self) -> yandex.cloud.organizationmanager.v1.group_mapping_pb2.GroupMappingItem: ...
    def __init__(
        self,
        *,
        item: yandex.cloud.organizationmanager.v1.group_mapping_pb2.GroupMappingItem | None = ...,
        action: global___GroupMappingItemDelta.Action.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "item", b"item"]) -> None: ...

global___GroupMappingItemDelta = GroupMappingItemDelta

@typing.final
class UpdateGroupMappingItemsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___UpdateGroupMappingItemsMetadata = UpdateGroupMappingItemsMetadata

@typing.final
class UpdateGroupMappingItemsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_MAPPING_ITEM_DELTAS_FIELD_NUMBER: builtins.int
    @property
    def group_mapping_item_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GroupMappingItemDelta]:
        """Effective changes that were applied"""

    def __init__(
        self,
        *,
        group_mapping_item_deltas: collections.abc.Iterable[global___GroupMappingItemDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_mapping_item_deltas", b"group_mapping_item_deltas"]) -> None: ...

global___UpdateGroupMappingItemsResponse = UpdateGroupMappingItemsResponse

@typing.final
class ListGroupMappingItemsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    page_size: builtins.int
    page_token: builtins.str
    filter: builtins.str
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListGroupMappingItemsRequest = ListGroupMappingItemsRequest

@typing.final
class ListGroupMappingItemsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_MAPPING_ITEMS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def group_mapping_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.group_mapping_pb2.GroupMappingItem]: ...
    def __init__(
        self,
        *,
        group_mapping_items: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.group_mapping_pb2.GroupMappingItem] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_mapping_items", b"group_mapping_items", "next_page_token", b"next_page_token"]) -> None: ...

global___ListGroupMappingItemsResponse = ListGroupMappingItemsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/elasticsearch/v1/config/elasticsearch.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/elasticsearch/v1/config/elasticsearch.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/mdb/elasticsearch/v1/config/elasticsearch.proto\x12(yandex.cloud.mdb.elasticsearch.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xb0\x01\n\x14\x45lasticsearchConfig7\x12\x35\n\x10max_clause_count\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1c\n\x14\x66ielddata_cache_size\x18\x04 \x01(\t\x12 \n\x18reindex_remote_whitelist\x18\x06 \x01(\t\x12\x1b\n\x13reindex_ssl_ca_path\x18\x07 \x01(\tJ\x04\x08\x05\x10\x06\"\xa6\x02\n\x17\x45lasticsearchConfigSet7\x12^\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.elasticsearch.v1.config.ElasticsearchConfig7B\x04\xe8\xc7\x31\x01\x12S\n\x0buser_config\x18\x02 \x01(\x0b\x32>.yandex.cloud.mdb.elasticsearch.v1.config.ElasticsearchConfig7\x12V\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32>.yandex.cloud.mdb.elasticsearch.v1.config.ElasticsearchConfig7B\x8a\x01\n,yandex.cloud.api.mdb.elasticsearch.v1.configZZgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1/config;elasticsearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.elasticsearch.v1.config.elasticsearch_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,yandex.cloud.api.mdb.elasticsearch.v1.configZZgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1/config;elasticsearch'
  _globals['_ELASTICSEARCHCONFIGSET7'].fields_by_name['effective_config']._loaded_options = None
  _globals['_ELASTICSEARCHCONFIGSET7'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_ELASTICSEARCHCONFIG7']._serialized_start=170
  _globals['_ELASTICSEARCHCONFIG7']._serialized_end=346
  _globals['_ELASTICSEARCHCONFIGSET7']._serialized_start=349
  _globals['_ELASTICSEARCHCONFIGSET7']._serialized_end=643
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datatransfer/v1/endpoint/common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datatransfer/v1/endpoint/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/datatransfer/v1/endpoint/common.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x1bgoogle/protobuf/empty.proto\"-\n\x07\x41ltName\x12\x11\n\tfrom_name\x18\x01 \x01(\t\x12\x0f\n\x07to_name\x18\x02 \x01(\t\" \n\x06Secret\x12\r\n\x03raw\x18\x01 \x01(\tH\x00\x42\x07\n\x05value\"\x87\x01\n\tColSchema\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x04type\x18\x02 \x01(\x0e\x32\x31.yandex.cloud.datatransfer.v1.endpoint.ColumnType\x12\x0b\n\x03key\x18\x03 \x01(\x08\x12\x10\n\x08required\x18\x04 \x01(\x08\x12\x0c\n\x04path\x18\x05 \x01(\t\"\x86\x01\n\x07TLSMode\x12*\n\x08\x64isabled\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x43\n\x07\x65nabled\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.TLSConfigH\x00\x42\n\n\x08tls_mode\"#\n\tTLSConfig\x12\x16\n\x0e\x63\x61_certificate\x18\x01 \x01(\t\".\n\x0b\x43olumnValue\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x42\x07\n\x05value\"\xc0\x01\n\x19\x44\x61taTransformationOptions\x12\x16\n\x0e\x63loud_function\x18\x01 \x01(\t\x12\x19\n\x11number_of_retries\x18\x02 \x01(\x03\x12\x13\n\x0b\x62uffer_size\x18\x03 \x01(\t\x12\x1d\n\x15\x62uffer_flush_interval\x18\x04 \x01(\t\x12\x1a\n\x12invocation_timeout\x18\x05 \x01(\t\x12\x1a\n\x12service_account_id\x18\x08 \x01(\tJ\x04\x08\x06\x10\x08\"S\n\tFieldList\x12@\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.ColSchemaJ\x04\x08\x01\x10\x02\"q\n\nDataSchema\x12\x15\n\x0bjson_fields\x18\x01 \x01(\tH\x00\x12\x42\n\x06\x66ields\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.FieldListH\x00\x42\x08\n\x06schema\"\x08\n\x06NoAuth\"G\n\x1b\x43onnectionManagerConnection\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x01(\t*h\n\x13ObjectTransferStage\x12%\n!OBJECT_TRANSFER_STAGE_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x42\x45\x46ORE_DATA\x10\x01\x12\x0e\n\nAFTER_DATA\x10\x02\x12\t\n\x05NEVER\x10\x03*U\n\rCleanupPolicy\x12\x1e\n\x1a\x43LEANUP_POLICY_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x08\n\x04\x44ROP\x10\x02\x12\x0c\n\x08TRUNCATE\x10\x03*\xc9\x01\n\nColumnType\x12\x1b\n\x17\x43OLUMN_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05INT32\x10\x01\x12\t\n\x05INT16\x10\x02\x12\x08\n\x04INT8\x10\x03\x12\n\n\x06UINT64\x10\x04\x12\n\n\x06UINT32\x10\x05\x12\n\n\x06UINT16\x10\x06\x12\t\n\x05UINT8\x10\x07\x12\n\n\x06\x44OUBLE\x10\x08\x12\x0b\n\x07\x42OOLEAN\x10\t\x12\n\n\x06STRING\x10\n\x12\x08\n\x04UTF8\x10\x0b\x12\x07\n\x03\x41NY\x10\x0c\x12\x0c\n\x08\x44\x41TETIME\x10\r\x12\t\n\x05INT64\x10\x0e\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint'
  _globals['_OBJECTTRANSFERSTAGE']._serialized_start=1041
  _globals['_OBJECTTRANSFERSTAGE']._serialized_end=1145
  _globals['_CLEANUPPOLICY']._serialized_start=1147
  _globals['_CLEANUPPOLICY']._serialized_end=1232
  _globals['_COLUMNTYPE']._serialized_start=1235
  _globals['_COLUMNTYPE']._serialized_end=1436
  _globals['_ALTNAME']._serialized_start=122
  _globals['_ALTNAME']._serialized_end=167
  _globals['_SECRET']._serialized_start=169
  _globals['_SECRET']._serialized_end=201
  _globals['_COLSCHEMA']._serialized_start=204
  _globals['_COLSCHEMA']._serialized_end=339
  _globals['_TLSMODE']._serialized_start=342
  _globals['_TLSMODE']._serialized_end=476
  _globals['_TLSCONFIG']._serialized_start=478
  _globals['_TLSCONFIG']._serialized_end=513
  _globals['_COLUMNVALUE']._serialized_start=515
  _globals['_COLUMNVALUE']._serialized_end=561
  _globals['_DATATRANSFORMATIONOPTIONS']._serialized_start=564
  _globals['_DATATRANSFORMATIONOPTIONS']._serialized_end=756
  _globals['_FIELDLIST']._serialized_start=758
  _globals['_FIELDLIST']._serialized_end=841
  _globals['_DATASCHEMA']._serialized_start=843
  _globals['_DATASCHEMA']._serialized_end=956
  _globals['_NOAUTH']._serialized_start=958
  _globals['_NOAUTH']._serialized_end=966
  _globals['_CONNECTIONMANAGERCONNECTION']._serialized_start=968
  _globals['_CONNECTIONMANAGERCONNECTION']._serialized_end=1039
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/analysis/utterance_statistics.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/analysis/utterance_statistics.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.speechsense.v1.analysis import statistics_common_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_statistics__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?yandex/cloud/speechsense/v1/analysis/utterance_statistics.proto\x12$yandex.cloud.speechsense.v1.analysis\x1a<yandex/cloud/speechsense/v1/analysis/statistics_common.proto\"\xbf\x03\n\x13UtteranceStatistics\x12\x13\n\x0bspeaker_tag\x18\x01 \x01(\t\x12W\n\x11speech_boundaries\x18\x02 \x01(\x0b\x32<.yandex.cloud.speechsense.v1.analysis.AudioSegmentBoundaries\x12\x17\n\x0ftotal_speech_ms\x18\x03 \x01(\x03\x12\x14\n\x0cspeech_ratio\x18\x04 \x01(\x01\x12\x18\n\x10total_silence_ms\x18\x05 \x01(\x03\x12\x15\n\rsilence_ratio\x18\x06 \x01(\x01\x12\x13\n\x0bwords_count\x18\x07 \x01(\x03\x12\x15\n\rletters_count\x18\x08 \x01(\x03\x12U\n\x10words_per_second\x18\t \x01(\x0b\x32;.yandex.cloud.speechsense.v1.analysis.DescriptiveStatistics\x12W\n\x12letters_per_second\x18\n \x01(\x0b\x32;.yandex.cloud.speechsense.v1.analysis.DescriptiveStatisticsB\x9a\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x18UtteranceStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.utterance_statistics_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\030UtteranceStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_UTTERANCESTATISTICS']._serialized_start=168
  _globals['_UTTERANCESTATISTICS']._serialized_end=615
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _State:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_State.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STATE_UNSPECIFIED: _State.ValueType  # 0
    ACTIVATED: _State.ValueType  # 1
    DEACTIVATED: _State.ValueType  # 2
    PENDING_ACTIVATION: _State.ValueType  # 3
    DEPRECATED: _State.ValueType  # 4
    DELETED: _State.ValueType  # 5

class State(_State, metaclass=_StateEnumTypeWrapper): ...

STATE_UNSPECIFIED: State.ValueType  # 0
ACTIVATED: State.ValueType  # 1
DEACTIVATED: State.ValueType  # 2
PENDING_ACTIVATION: State.ValueType  # 3
DEPRECATED: State.ValueType  # 4
DELETED: State.ValueType  # 5
global___State = State

class _ResourceType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ResourceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ResourceType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESOURCE_TYPE_UNSPECIFIED: _ResourceType.ValueType  # 0
    SAAS: _ResourceType.ValueType  # 1
    K8S: _ResourceType.ValueType  # 2
    COMPUTE: _ResourceType.ValueType  # 3
    CLOUD_APPS: _ResourceType.ValueType  # 4

class ResourceType(_ResourceType, metaclass=_ResourceTypeEnumTypeWrapper): ...

RESOURCE_TYPE_UNSPECIFIED: ResourceType.ValueType  # 0
SAAS: ResourceType.ValueType  # 1
K8S: ResourceType.ValueType  # 2
COMPUTE: ResourceType.ValueType  # 3
CLOUD_APPS: ResourceType.ValueType  # 4
global___ResourceType = ResourceType

@typing.final
class ProductInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ResourceMetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_METADATA_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    SAAS_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    resource_id: builtins.str
    resource_type: global___ResourceType.ValueType
    state: global___State.ValueType
    @property
    def resource_metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def saas_info(self) -> global___SaasInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        resource_id: builtins.str = ...,
        resource_type: global___ResourceType.ValueType = ...,
        resource_metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        state: global___State.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        saas_info: global___SaasInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "resource_info", b"resource_info", "saas_info", b"saas_info", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "id", b"id", "resource_id", b"resource_id", "resource_info", b"resource_info", "resource_metadata", b"resource_metadata", "resource_type", b"resource_type", "saas_info", b"saas_info", "state", b"state", "updated_at", b"updated_at"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["resource_info", b"resource_info"]) -> typing.Literal["saas_info"] | None: ...

global___ProductInstance = ProductInstance

@typing.final
class SaasInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def data(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        data: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "id", b"id"]) -> None: ...

global___SaasInfo = SaasInfo



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/airflow/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/airflow/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.airflow.v1 import common_pb2 as yandex_dot_cloud_dot_airflow_dot_v1_dot_common__pb2
from yandex.cloud.airflow.v1 import maintenance_pb2 as yandex_dot_cloud_dot_airflow_dot_v1_dot_maintenance__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/airflow/v1/cluster.proto\x12\x17yandex.cloud.airflow.v1\x1a$yandex/cloud/airflow/v1/common.proto\x1a)yandex/cloud/airflow/v1/maintenance.proto\x1a\x1dyandex/cloud/validation.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xde\x07\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12<\n\x06labels\x18\x06 \x03(\x0b\x32,.yandex.cloud.airflow.v1.Cluster.LabelsEntry\x12\x37\n\nmonitoring\x18\x08 \x03(\x0b\x32#.yandex.cloud.airflow.v1.Monitoring\x12\x36\n\x06\x63onfig\x18\t \x01(\x0b\x32&.yandex.cloud.airflow.v1.ClusterConfig\x12/\n\x06health\x18\n \x01(\x0e\x32\x1f.yandex.cloud.airflow.v1.Health\x12\x37\n\x06status\x18\x0b \x01(\x0e\x32\'.yandex.cloud.airflow.v1.Cluster.Status\x12\x37\n\x07network\x18\x0c \x01(\x0b\x32&.yandex.cloud.airflow.v1.NetworkConfig\x12:\n\tcode_sync\x18\r \x01(\x0b\x32\'.yandex.cloud.airflow.v1.CodeSyncConfig\x12\x1b\n\x13\x64\x65letion_protection\x18\x0e \x01(\x08\x12\x15\n\rwebserver_url\x18\x0f \x01(\t\x12$\n\x12service_account_id\x18\x10 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x37\n\x07logging\x18\x11 \x01(\x0b\x32&.yandex.cloud.airflow.v1.LoggingConfig\x12\x46\n\x12maintenance_window\x18\x12 \x01(\x0b\x32*.yandex.cloud.airflow.v1.MaintenanceWindow\x12H\n\x11planned_operation\x18\x13 \x01(\x0b\x32-.yandex.cloud.airflow.v1.MaintenanceOperation\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08STARTING\x10\x06\x12\x0c\n\x08UPDATING\x10\x07J\x04\x08\x07\x10\x08\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\x87\x04\n\rClusterConfig\x12\x16\n\nversion_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x37\n\x07\x61irflow\x18\x02 \x01(\x0b\x32&.yandex.cloud.airflow.v1.AirflowConfig\x12\x41\n\twebserver\x18\x03 \x01(\x0b\x32(.yandex.cloud.airflow.v1.WebserverConfigB\x04\xe8\xc7\x31\x01\x12\x41\n\tscheduler\x18\x04 \x01(\x0b\x32(.yandex.cloud.airflow.v1.SchedulerConfigB\x04\xe8\xc7\x31\x01\x12;\n\ttriggerer\x18\x05 \x01(\x0b\x32(.yandex.cloud.airflow.v1.TriggererConfig\x12;\n\x06worker\x18\x06 \x01(\x0b\x32%.yandex.cloud.airflow.v1.WorkerConfigB\x04\xe8\xc7\x31\x01\x12;\n\x0c\x64\x65pendencies\x18\x07 \x01(\x0b\x32%.yandex.cloud.airflow.v1.Dependencies\x12\x37\n\x07lockbox\x18\x08 \x01(\x0b\x32&.yandex.cloud.airflow.v1.LockboxConfig\x12\x17\n\x0f\x61irflow_version\x18\t \x01(\t\x12\x16\n\x0epython_version\x18\n \x01(\t\"\x82\x01\n\rAirflowConfig\x12\x42\n\x06\x63onfig\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.airflow.v1.AirflowConfig.ConfigEntry\x1a-\n\x0b\x43onfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n\x0fWebserverConfig\x12\x18\n\x05\x63ount\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-512\x12\x35\n\tresources\x18\x02 \x01(\x0b\x32\".yandex.cloud.airflow.v1.Resources\"b\n\x0fSchedulerConfig\x12\x18\n\x05\x63ount\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-512\x12\x35\n\tresources\x18\x02 \x01(\x0b\x32\".yandex.cloud.airflow.v1.Resources\"b\n\x0fTriggererConfig\x12\x18\n\x05\x63ount\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-512\x12\x35\n\tresources\x18\x02 \x01(\x0b\x32\".yandex.cloud.airflow.v1.Resources\"\x81\x01\n\x0cWorkerConfig\x12\x1c\n\tmin_count\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-512\x12\x1c\n\tmax_count\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-512\x12\x35\n\tresources\x18\x03 \x01(\x0b\x32\".yandex.cloud.airflow.v1.Resources\":\n\x0c\x44\x65pendencies\x12\x14\n\x0cpip_packages\x18\x01 \x03(\t\x12\x14\n\x0c\x64\x65\x62_packages\x18\x02 \x03(\t\"?\n\rNetworkConfig\x12\x12\n\nsubnet_ids\x18\x01 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x02 \x03(\t\"\x1a\n\x08S3Config\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\"Q\n\x0e\x43odeSyncConfig\x12/\n\x02s3\x18\x01 \x01(\x0b\x32!.yandex.cloud.airflow.v1.S3ConfigH\x00\x42\x0e\n\x06source\x12\x04\xc0\xc1\x31\x01\"\xe2\x01\n\rLoggingConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x38\n\tfolder_id\x18\x02 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12;\n\x0clog_group_id\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12:\n\tmin_level\x18\x04 \x01(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\r\n\x0b\x64\x65stination\" \n\rLockboxConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x42\x62\n\x1byandex.cloud.api.airflow.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/airflow/v1;airflowb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.airflow.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.airflow.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/airflow/v1;airflow'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CLUSTERCONFIG'].fields_by_name['version_id']._loaded_options = None
  _globals['_CLUSTERCONFIG'].fields_by_name['version_id']._serialized_options = b'\030\001'
  _globals['_CLUSTERCONFIG'].fields_by_name['webserver']._loaded_options = None
  _globals['_CLUSTERCONFIG'].fields_by_name['webserver']._serialized_options = b'\350\3071\001'
  _globals['_CLUSTERCONFIG'].fields_by_name['scheduler']._loaded_options = None
  _globals['_CLUSTERCONFIG'].fields_by_name['scheduler']._serialized_options = b'\350\3071\001'
  _globals['_CLUSTERCONFIG'].fields_by_name['worker']._loaded_options = None
  _globals['_CLUSTERCONFIG'].fields_by_name['worker']._serialized_options = b'\350\3071\001'
  _globals['_AIRFLOWCONFIG_CONFIGENTRY']._loaded_options = None
  _globals['_AIRFLOWCONFIG_CONFIGENTRY']._serialized_options = b'8\001'
  _globals['_WEBSERVERCONFIG'].fields_by_name['count']._loaded_options = None
  _globals['_WEBSERVERCONFIG'].fields_by_name['count']._serialized_options = b'\372\3071\0051-512'
  _globals['_SCHEDULERCONFIG'].fields_by_name['count']._loaded_options = None
  _globals['_SCHEDULERCONFIG'].fields_by_name['count']._serialized_options = b'\372\3071\0051-512'
  _globals['_TRIGGERERCONFIG'].fields_by_name['count']._loaded_options = None
  _globals['_TRIGGERERCONFIG'].fields_by_name['count']._serialized_options = b'\372\3071\0050-512'
  _globals['_WORKERCONFIG'].fields_by_name['min_count']._loaded_options = None
  _globals['_WORKERCONFIG'].fields_by_name['min_count']._serialized_options = b'\372\3071\0050-512'
  _globals['_WORKERCONFIG'].fields_by_name['max_count']._loaded_options = None
  _globals['_WORKERCONFIG'].fields_by_name['max_count']._serialized_options = b'\372\3071\0051-512'
  _globals['_CODESYNCCONFIG'].oneofs_by_name['source']._loaded_options = None
  _globals['_CODESYNCCONFIG'].oneofs_by_name['source']._serialized_options = b'\300\3011\001'
  _globals['_LOGGINGCONFIG'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LOGGINGCONFIG'].fields_by_name['folder_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _globals['_LOGGINGCONFIG'].fields_by_name['log_group_id']._loaded_options = None
  _globals['_LOGGINGCONFIG'].fields_by_name['log_group_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _globals['_CLUSTER']._serialized_start=253
  _globals['_CLUSTER']._serialized_end=1243
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=1069
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=1114
  _globals['_CLUSTER_STATUS']._serialized_start=1116
  _globals['_CLUSTER_STATUS']._serialized_end=1237
  _globals['_MONITORING']._serialized_start=1245
  _globals['_MONITORING']._serialized_end=1306
  _globals['_CLUSTERCONFIG']._serialized_start=1309
  _globals['_CLUSTERCONFIG']._serialized_end=1828
  _globals['_AIRFLOWCONFIG']._serialized_start=1831
  _globals['_AIRFLOWCONFIG']._serialized_end=1961
  _globals['_AIRFLOWCONFIG_CONFIGENTRY']._serialized_start=1916
  _globals['_AIRFLOWCONFIG_CONFIGENTRY']._serialized_end=1961
  _globals['_WEBSERVERCONFIG']._serialized_start=1963
  _globals['_WEBSERVERCONFIG']._serialized_end=2061
  _globals['_SCHEDULERCONFIG']._serialized_start=2063
  _globals['_SCHEDULERCONFIG']._serialized_end=2161
  _globals['_TRIGGERERCONFIG']._serialized_start=2163
  _globals['_TRIGGERERCONFIG']._serialized_end=2261
  _globals['_WORKERCONFIG']._serialized_start=2264
  _globals['_WORKERCONFIG']._serialized_end=2393
  _globals['_DEPENDENCIES']._serialized_start=2395
  _globals['_DEPENDENCIES']._serialized_end=2453
  _globals['_NETWORKCONFIG']._serialized_start=2455
  _globals['_NETWORKCONFIG']._serialized_end=2518
  _globals['_S3CONFIG']._serialized_start=2520
  _globals['_S3CONFIG']._serialized_end=2546
  _globals['_CODESYNCCONFIG']._serialized_start=2548
  _globals['_CODESYNCCONFIG']._serialized_end=2629
  _globals['_LOGGINGCONFIG']._serialized_start=2632
  _globals['_LOGGINGCONFIG']._serialized_end=2858
  _globals['_LOCKBOXCONFIG']._serialized_start=2860
  _globals['_LOCKBOXCONFIG']._serialized_end=2892
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetOsLoginSettingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id"]) -> None: ...

global___GetOsLoginSettingsRequest = GetOsLoginSettingsRequest

@typing.final
class OsLoginSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SSH_KEY_SETTINGS_FIELD_NUMBER: builtins.int
    SSH_CERTIFICATE_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def user_ssh_key_settings(self) -> global___UserSshKeySettings: ...
    @property
    def ssh_certificate_settings(self) -> global___SshCertificateSettings: ...
    def __init__(
        self,
        *,
        user_ssh_key_settings: global___UserSshKeySettings | None = ...,
        ssh_certificate_settings: global___SshCertificateSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ssh_certificate_settings", b"ssh_certificate_settings", "user_ssh_key_settings", b"user_ssh_key_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ssh_certificate_settings", b"ssh_certificate_settings", "user_ssh_key_settings", b"user_ssh_key_settings"]) -> None: ...

global___OsLoginSettings = OsLoginSettings

@typing.final
class UserSshKeySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    ALLOW_MANAGE_OWN_KEYS_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    allow_manage_own_keys: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        allow_manage_own_keys: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["allow_manage_own_keys", b"allow_manage_own_keys", "enabled", b"enabled"]) -> None: ...

global___UserSshKeySettings = UserSshKeySettings

@typing.final
class SshCertificateSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enabled", b"enabled"]) -> None: ...

global___SshCertificateSettings = SshCertificateSettings

@typing.final
class UpdateOsLoginSettingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class UserSshKeySettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        ALLOW_MANAGE_OWN_KEYS_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        allow_manage_own_keys: builtins.bool
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            allow_manage_own_keys: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["allow_manage_own_keys", b"allow_manage_own_keys", "enabled", b"enabled"]) -> None: ...

    @typing.final
    class SshCertificateSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled"]) -> None: ...

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    USER_SSH_KEY_SETTINGS_FIELD_NUMBER: builtins.int
    SSH_CERTIFICATE_SETTINGS_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    @property
    def user_ssh_key_settings(self) -> global___UpdateOsLoginSettingsRequest.UserSshKeySettings: ...
    @property
    def ssh_certificate_settings(self) -> global___UpdateOsLoginSettingsRequest.SshCertificateSettings: ...
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        user_ssh_key_settings: global___UpdateOsLoginSettingsRequest.UserSshKeySettings | None = ...,
        ssh_certificate_settings: global___UpdateOsLoginSettingsRequest.SshCertificateSettings | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ssh_certificate_settings", b"ssh_certificate_settings", "update_mask", b"update_mask", "user_ssh_key_settings", b"user_ssh_key_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id", "ssh_certificate_settings", b"ssh_certificate_settings", "update_mask", b"update_mask", "user_ssh_key_settings", b"user_ssh_key_settings"]) -> None: ...

global___UpdateOsLoginSettingsRequest = UpdateOsLoginSettingsRequest

@typing.final
class SetDefaultOsLoginProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OS_LOGIN_PROFILE_ID_FIELD_NUMBER: builtins.int
    os_login_profile_id: builtins.str
    def __init__(
        self,
        *,
        os_login_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["os_login_profile_id", b"os_login_profile_id"]) -> None: ...

global___SetDefaultOsLoginProfileRequest = SetDefaultOsLoginProfileRequest

@typing.final
class GetOsLoginProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OS_LOGIN_PROFILE_ID_FIELD_NUMBER: builtins.int
    os_login_profile_id: builtins.str
    def __init__(
        self,
        *,
        os_login_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["os_login_profile_id", b"os_login_profile_id"]) -> None: ...

global___GetOsLoginProfileRequest = GetOsLoginProfileRequest

@typing.final
class ListOsLoginProfilesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    page_size: builtins.int
    page_token: builtins.str
    filter: builtins.str
    """A filter expression that filters profiles listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering by subject_id, uid or login.
    2. An `=` operator.
    3. The value in double quotes (`"`).
    E.g. login="example-login"
    """
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListOsLoginProfilesRequest = ListOsLoginProfilesRequest

@typing.final
class ListOsLoginProfilesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROFILES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OsLoginProfile]: ...
    def __init__(
        self,
        *,
        profiles: collections.abc.Iterable[global___OsLoginProfile] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "profiles", b"profiles"]) -> None: ...

global___ListOsLoginProfilesResponse = ListOsLoginProfilesResponse

@typing.final
class OsLoginProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    IS_DEFAULT_FIELD_NUMBER: builtins.int
    HOME_DIRECTORY_FIELD_NUMBER: builtins.int
    SHELL_FIELD_NUMBER: builtins.int
    id: builtins.str
    organization_id: builtins.str
    subject_id: builtins.str
    login: builtins.str
    uid: builtins.int
    is_default: builtins.bool
    home_directory: builtins.str
    shell: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        organization_id: builtins.str = ...,
        subject_id: builtins.str = ...,
        login: builtins.str = ...,
        uid: builtins.int = ...,
        is_default: builtins.bool = ...,
        home_directory: builtins.str = ...,
        shell: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["home_directory", b"home_directory", "id", b"id", "is_default", b"is_default", "login", b"login", "organization_id", b"organization_id", "shell", b"shell", "subject_id", b"subject_id", "uid", b"uid"]) -> None: ...

global___OsLoginProfile = OsLoginProfile

@typing.final
class UpdateOsLoginProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OS_LOGIN_PROFILE_ID_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    HOME_DIRECTORY_FIELD_NUMBER: builtins.int
    SHELL_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    os_login_profile_id: builtins.str
    login: builtins.str
    """must not contain . or end in ~"""
    uid: builtins.int
    """1000 - 2^63 - 1"""
    home_directory: builtins.str
    shell: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    def __init__(
        self,
        *,
        os_login_profile_id: builtins.str = ...,
        login: builtins.str = ...,
        uid: builtins.int = ...,
        home_directory: builtins.str = ...,
        shell: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["home_directory", b"home_directory", "login", b"login", "os_login_profile_id", b"os_login_profile_id", "shell", b"shell", "uid", b"uid", "update_mask", b"update_mask"]) -> None: ...

global___UpdateOsLoginProfileRequest = UpdateOsLoginProfileRequest

@typing.final
class DeleteOsLoginProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___DeleteOsLoginProfileRequest = DeleteOsLoginProfileRequest

@typing.final
class CreateOsLoginProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    HOME_DIRECTORY_FIELD_NUMBER: builtins.int
    SHELL_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    subject_id: builtins.str
    login: builtins.str
    """must not contain . or end in ~"""
    uid: builtins.int
    """1000 - 2^63 - 1"""
    home_directory: builtins.str
    shell: builtins.str
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        subject_id: builtins.str = ...,
        login: builtins.str = ...,
        uid: builtins.int = ...,
        home_directory: builtins.str = ...,
        shell: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["home_directory", b"home_directory", "login", b"login", "organization_id", b"organization_id", "shell", b"shell", "subject_id", b"subject_id", "uid", b"uid"]) -> None: ...

global___CreateOsLoginProfileRequest = CreateOsLoginProfileRequest

@typing.final
class UpdateOsLoginProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OS_LOGIN_PROFILE_ID_FIELD_NUMBER: builtins.int
    os_login_profile_id: builtins.str
    def __init__(
        self,
        *,
        os_login_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["os_login_profile_id", b"os_login_profile_id"]) -> None: ...

global___UpdateOsLoginProfileMetadata = UpdateOsLoginProfileMetadata

@typing.final
class DeleteOsLoginProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OS_LOGIN_PROFILE_ID_FIELD_NUMBER: builtins.int
    os_login_profile_id: builtins.str
    def __init__(
        self,
        *,
        os_login_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["os_login_profile_id", b"os_login_profile_id"]) -> None: ...

global___DeleteOsLoginProfileMetadata = DeleteOsLoginProfileMetadata

@typing.final
class CreateOsLoginProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OS_LOGIN_PROFILE_ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    os_login_profile_id: builtins.str
    organization_id: builtins.str
    subject_id: builtins.str
    def __init__(
        self,
        *,
        os_login_profile_id: builtins.str = ...,
        organization_id: builtins.str = ...,
        subject_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id", "os_login_profile_id", b"os_login_profile_id", "subject_id", b"subject_id"]) -> None: ...

global___CreateOsLoginProfileMetadata = CreateOsLoginProfileMetadata

@typing.final
class UpdateOsLoginSettingsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id"]) -> None: ...

global___UpdateOsLoginSettingsMetadata = UpdateOsLoginSettingsMetadata

@typing.final
class SetDefaultOsLoginProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREVIOUS_DEFAULT_PROFILE_ID_FIELD_NUMBER: builtins.int
    CURRENT_DEFAULT_PROFILE_ID_FIELD_NUMBER: builtins.int
    previous_default_profile_id: builtins.str
    current_default_profile_id: builtins.str
    def __init__(
        self,
        *,
        previous_default_profile_id: builtins.str = ...,
        current_default_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["current_default_profile_id", b"current_default_profile_id", "previous_default_profile_id", b"previous_default_profile_id"]) -> None: ...

global___SetDefaultOsLoginProfileMetadata = SetDefaultOsLoginProfileMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.eventrouter.v1.bus_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetBusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUS_ID_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus to get."""
    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id"]) -> None: ...

global___GetBusRequest = GetBusRequest

@typing.final
class ListBusesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list buses in."""
    page_size: builtins.int
    """Maximum number of buses to return."""
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListBusesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """Supported fields for filter:
      name
      created_at
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBusesRequest = ListBusesRequest

@typing.final
class ListBusesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUSES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list of buses."""
    @property
    def buses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.eventrouter.v1.bus_pb2.Bus]:
        """List of buses."""

    def __init__(
        self,
        *,
        buses: collections.abc.Iterable[yandex.cloud.serverless.eventrouter.v1.bus_pb2.Bus] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["buses", b"buses", "next_page_token", b"next_page_token"]) -> None: ...

global___ListBusesResponse = ListBusesResponse

@typing.final
class CreateBusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    LOGGING_ENABLED_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a bus in."""
    name: builtins.str
    """Name of the bus."""
    description: builtins.str
    """Description of the bus."""
    deletion_protection: builtins.bool
    """Flag that disallow deletion of the bus."""
    logging_enabled: builtins.bool
    """Is logging from the bus enabled."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels for the bus."""

    @property
    def log_options(self) -> yandex.cloud.serverless.eventrouter.v1.bus_pb2.LogOptions:
        """Options for logging from the bus."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        logging_enabled: builtins.bool = ...,
        log_options: yandex.cloud.serverless.eventrouter.v1.bus_pb2.LogOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["log_options", b"log_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "log_options", b"log_options", "logging_enabled", b"logging_enabled", "name", b"name"]) -> None: ...

global___CreateBusRequest = CreateBusRequest

@typing.final
class CreateBusMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUS_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus that is being created."""
    folder_id: builtins.str
    """ID of the folder that the bus is being created in."""
    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id", "folder_id", b"folder_id"]) -> None: ...

global___CreateBusMetadata = CreateBusMetadata

@typing.final
class UpdateBusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    BUS_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    LOGGING_ENABLED_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus to update."""
    name: builtins.str
    """New name of the bus."""
    description: builtins.str
    """ New description of the bus."""
    deletion_protection: builtins.bool
    """New flag that disallow deletion of the bus."""
    logging_enabled: builtins.bool
    """Is logging from the bus enabled."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the bus are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New labels of the bus."""

    @property
    def log_options(self) -> yandex.cloud.serverless.eventrouter.v1.bus_pb2.LogOptions:
        """New options for logging from the bus."""

    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        logging_enabled: builtins.bool = ...,
        log_options: yandex.cloud.serverless.eventrouter.v1.bus_pb2.LogOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["log_options", b"log_options", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id", "deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "log_options", b"log_options", "logging_enabled", b"logging_enabled", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateBusRequest = UpdateBusRequest

@typing.final
class UpdateBusMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUS_ID_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus that is being updated."""
    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id"]) -> None: ...

global___UpdateBusMetadata = UpdateBusMetadata

@typing.final
class DeleteBusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUS_ID_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus to delete."""
    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id"]) -> None: ...

global___DeleteBusRequest = DeleteBusRequest

@typing.final
class DeleteBusMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUS_ID_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus that is being deleted."""
    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id"]) -> None: ...

global___DeleteBusMetadata = DeleteBusMetadata

@typing.final
class ListBusOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUS_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus to list operations for."""
    page_size: builtins.int
    """Maximum number of operations to return."""
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListBusesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """Supported attributes for filter:
      description
      created_at
      modified_at
      created_by
      done
    """
    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBusOperationsRequest = ListBusOperationsRequest

@typing.final
class ListBusOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list of operations."""
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified bus."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListBusOperationsResponse = ListBusOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.cdn.v1.resource_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Rule(google.protobuf.message.Message):
    """Resource rule."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RULE_PATTERN_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    id: builtins.int
    """Rule ID."""
    name: builtins.str
    """Rule name."""
    rule_pattern: builtins.str
    """Rule pattern.
    Must be a valid regular expression.
    """
    @property
    def options(self) -> yandex.cloud.cdn.v1.resource_pb2.ResourceOptions: ...
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        rule_pattern: builtins.str = ...,
        options: yandex.cloud.cdn.v1.resource_pb2.ResourceOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name", "options", b"options", "rule_pattern", b"rule_pattern"]) -> None: ...

global___Rule = Rule
